# -*- coding: utf-8 -*-
"""
    tipfy.ext.mail
    ~~~~~~~~~~~~~~

    A simple :class:`tipfy.RequestHandler` to help with receiving mail.

    Ported from the original App Engine library.

    :copyright: 2007 Google Inc.
    :license: Apache 2.0 License, see LICENSE.txt for more details.
"""
from google.appengine.api import mail

from tipfy import RequestHandler


class InboundMailHandler(RequestHandler):
    """Base class for inbound mail handlers. Example:

        # Sub-class overrides receive method.
        class HelloReceiver(InboundMailHandler):

            def receive(self, mail_message):
                logging.info('Received greeting from %s: %s' % (
                    mail_message.sender, mail_message.body))
    """
    def post(self, **kwargs):
        """Transforms body to email request.

        :param kwargs:
            Keyword arguments from the matched URL rule.
        """
        return self.receive(mail.InboundEmailMessage(self.request.data),
            **kwargs)

    def receive(self, mail_message, **kwargs):
        """Receive an email message.

        Override this method to implement an email receiver.

        :param mail_message:
            InboundEmailMessage instance representing received email.
        :param kwargs:
            Keyword arguments from the matched URL rule.
        """
        raise NotImplementedError()



"""
tipfy.ext.mail
==============

This extension provides a handler for inbound emails for tipfy, the almighty
little framework for Google App Engine.

Links
-----
* `Tipfy's website <http://www.tipfy.org/>`_
* `API Documentation <http://www.tipfy.org/docs/>`_
* `Wiki <http://www.tipfy.org/wiki/>`_
* `Discussion Group <http://groups.google.com/group/tipfy>`_
* `Issue Tracker <http://code.google.com/p/tipfy/issues/list>`_
* `Repository <http://code.google.com/p/tipfy/>`_
"""
from setuptools import setup

setup(
    name = 'tipfy.ext.mail',
    version = '0.5.5',
    license = 'BSD',
    url = 'http://www.tipfy.org/',
    description = 'Inbound mail extension for tipfy',
    long_description=__doc__,
    author = 'Rodrigo Moraes',
    author_email = 'rodrigo.moraes@gmail.com',
    zip_safe = False,
    platforms='any',
    packages = [
        'tipfy',
        'tipfy.ext',
    ],
    namespace_packages = [
        'tipfy',
        'tipfy.ext',
    ],
    include_package_data=True,
    install_requires = [
        'tipfy',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
